@@ -2,9 +2,10 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-from compas.datastructures.mesh.core import BaseMesh
+from compas.datastructures.mesh.core import Mesh as BaseMesh
 from compas.datastructures.mesh.core import mesh_collapse_edge
 from compas.datastructures.mesh.core import mesh_split_edge
+from compas.datastructures.mesh.core import mesh_split_face
 
 from compas.datastructures.mesh.bbox import mesh_bounding_box
 from compas.datastructures.mesh.bbox import mesh_bounding_box_xy
@@ -24,8 +25,14 @@ __all__ = ['Mesh']
 
 
 class Mesh(BaseMesh):
+    """Implementation of the base mesh data structure that adds some of the mesh algorithms as methods.
 
-    # provide numpy versions where possible under same name?
+    Examples
+    --------
+    >>> mesh = Mesh.from_polyhedron(6)
+    """
+
+    __module__ = "compas.datastructures"
 
     bounding_box = mesh_bounding_box
     bounding_box_xy = mesh_bounding_box_xy
@@ -38,6 +45,7 @@ class Mesh(BaseMesh):
     smooth_centroid = mesh_smooth_centroid
     smooth_area = mesh_smooth_area
     split_edge = mesh_split_edge
+    split_face = mesh_split_face
     transform = mesh_transform
     transformed = mesh_transformed
     unify_cycles = mesh_unify_cycles
@@ -63,30 +71,61 @@ if __name__ == "__main__":
 
     mesh = Mesh.from_obj(compas.get('faces.obj'))
 
-    mesh.update_default_face_attributes({'a': 1})
+    mesh.update_default_vertex_attributes({'v': 3})
+    mesh.update_default_face_attributes({'f': 1})
+    mesh.update_default_edge_attributes({'is_edge': True})
 
-    # for key, attr in mesh.vertices(True):
-    #     print(key, attr)
+    # key = mesh.get_any_vertex()
+    # fkey = mesh.get_any_face()
+    # ekey = mesh.get_any_edge()
 
-    # for key, attr in mesh.faces(True):
-    #     print(key, attr)
+    # mesh.vertex_attribute(key, 'v', 0)
+    # mesh.face_attribute(fkey, 'f', 5)
+    # mesh.edge_attribute(ekey, 'is_edge', False)
 
+    # print(list(mesh.vertices_where({'v': 0})))
+    # print(list(mesh.faces_where({'f': 5})))
+    # print(list(mesh.edges_where({'is_edge': False})))
+
+    # # for key, attr in mesh.vertices(True):
+    # #     print(key, attr)
+
+    # # for key, attr in mesh.faces(True):
+    # #     print(key, attr)
+
+    print()
+    print()
+    # # for key, attr in mesh.edges(True):
+    # #     print(key, attr)
+
+    for key in mesh.edges_on_boundary():
+        mesh.edge_attribute(key, 'is_edge', False)
+
+    # print()
     # for key, attr in mesh.edges(True):
     #     print(key, attr)
 
-    # xyz = mesh.vertices_attributes('xyz')
-    # print(xyz)
+    # print()
+    for key in mesh.edges_where({'is_edge': False}):
+        print(key)
 
-    # attr = mesh.vertex_attributes(0)
-    # print(attr)
+    # # print()
+    # # for key in mesh.edges_on_boundary():
+    # #     print(key, mesh.edge_attribute(key, 'is_edge'))
 
-    attr = mesh.face_attributes(0)
-    attr.custom_only = True
-    print(attr)
-    print(attr.keys())
-    print(list(attr.keys()))
+    # # xyz = mesh.vertices_attributes('xyz')
+    # # print(xyz)
 
-    # attr = mesh.edge_attributes((0, 1))
-    # print(attr)
+    # # attr = mesh.vertex_attributes(0)
+    # # print(attr)
 
-    # print(mesh)
+    # # attr = mesh.face_attributes(0)
+    # # attr.custom_only = True
+    # # print(attr)
+    # # print(attr.keys())
+    # # print(list(attr.keys()))
+
+    # # attr = mesh.edge_attributes((0, 1))
+    # # print(attr)
+
+    # # print(mesh)
