@@ -73,15 +73,15 @@ def delaunay_from_points(points, boundary=None, holes=None, tiny=1e-12):
 
     def super_triangle(coords):
         centpt = centroid_points(coords)
-        bbpts  = bounding_box(coords)
-        dis    = distance_point_point(bbpts[0], bbpts[2])
-        dis    = dis * 300
-        v1     = (0 * dis, 2 * dis, 0)
-        v2     = (1.73205 * dis, -1.0000000000001 * dis, 0)  # due to numerical issues
-        v3     = (-1.73205 * dis, -1 * dis, 0)
-        pt1    = add_vectors(centpt, v1)
-        pt2    = add_vectors(centpt, v2)
-        pt3    = add_vectors(centpt, v3)
+        bbpts = bounding_box(coords)
+        dis = distance_point_point(bbpts[0], bbpts[2])
+        dis = dis * 300
+        v1 = (0 * dis, 2 * dis, 0)
+        v2 = (1.73205 * dis, -1.0000000000001 * dis, 0)  # due to numerical issues
+        v3 = (-1.73205 * dis, -1 * dis, 0)
+        pt1 = add_vectors(centpt, v1)
+        pt2 = add_vectors(centpt, v2)
+        pt3 = add_vectors(centpt, v3)
         return pt1, pt2, pt3
 
     mesh = Mesh()
@@ -131,9 +131,9 @@ def delaunay_from_points(points, boundary=None, holes=None, tiny=1e-12):
             fkey = newtris.pop()
 
             # get opposite_face
-            keys  = mesh.face_vertices(fkey)
-            s     = list(set(keys) - set([key]))
-            u, v  = s[0], s[1]
+            keys = mesh.face_vertices(fkey)
+            s = list(set(keys) - set([key]))
+            u, v = s[0], s[1]
             fkey1 = mesh.halfedge[u][v]
 
             if fkey1 != fkey:
@@ -260,19 +260,20 @@ def delaunay_from_points(points, boundary=None, holes=None, tiny=1e-12):
 
 if __name__ == "__main__":
 
-    from compas.datastructures import Mesh
-    from compas.geometry import pointcloud_xy
-    from compas.geometry import delaunay_from_points
-    from compas_plotters import MeshPlotter
+    pass
 
-    points = pointcloud_xy(20, (0, 50))
-    faces = delaunay_from_points(points)
+    # from compas.datastructures import Mesh
+    # from compas.geometry import pointcloud_xy
+    # from compas_plotters import MeshPlotter
 
-    delaunay = Mesh.from_vertices_and_faces(points, faces)
+    # points = pointcloud_xy(20, (0, 50))
+    # faces = delaunay_from_points(points)
 
-    plotter = MeshPlotter(delaunay, figsize=(12, 8))
+    # delaunay = Mesh.from_vertices_and_faces(points, faces)
 
-    plotter.draw_vertices(radius=0.1)
-    plotter.draw_faces()
+    # plotter = MeshPlotter(delaunay, figsize=(12, 8))
 
-    plotter.show()
+    # plotter.draw_vertices(radius=0.1)
+    # plotter.draw_faces()
+
+    # plotter.show()
