@@ -6,7 +6,6 @@ import compas
 
 try:
     import Grasshopper as gh
-    import System
 except ImportError:
     compas.raise_if_ironpython()
 
@@ -39,3 +38,11 @@ def update_component(ghenv, delay):
 
     ghdoc.ScheduleSolution(
         delay, gh.Kernel.GH_Document.GH_ScheduleDelegate(callback))
+
+
+# ==============================================================================
+# Main
+# ==============================================================================
+
+if __name__ == '__main__':
+    pass
